# Geographical XGBoost
An implementation of XGBoost for geographical anlaysis

# Installation
pip install geoxgboost

# Tutorial
A complete tutorial presenting how to create a project in PyCharm, install geoxgboost and run the code in demo data. 

# Demo data
Boston housing dataset